import React from "react";
import { useState, forwardRef, useMemo } from "react";
import PropTypes from "prop-types";
import { Editor, EditorState, ContentState } from "draft-js";
import highlightToCompositeDecorator from "./highlightToCompositeDecorator.js";
var HighlightWithinTextarea = forwardRef(function (props, ref) {
  var placeholder = props.placeholder,
      highlight = props.highlight,
      onChange = props.onChange,
      value = props.value;

  var _useState = useState({
    prev: {
      value: null,
      editorState: null
    },
    next: {
      value: null,
      editorState: null
    }
  }),
      onChangeState = _useState[0],
      setOnChangeState = _useState[1];

  var editorState;

  if (value === onChangeState.next.value) {
    editorState = onChangeState.next.editorState;
  } else if (value === onChangeState.prev.value) {
    editorState = onChangeState.prev.editorState;
  } else {
    var contentState = ContentState.createFromText(value);
    editorState = EditorState.createWithContent(contentState);
  }

  var decorator = useMemo(function () {
    return highlightToCompositeDecorator(highlight);
  }, [highlight]);

  if (decorator !== editorState.decorator) {
    editorState = EditorState.set(editorState, {
      decorator: decorator
    });
  }

  var onDraftChange = function onDraftChange(editorState) {
    var value = editorState.getCurrentContent().getPlainText();
    setOnChangeState({
      prev: onChangeState.next,
      next: {
        value: value,
        editorState: editorState
      }
    });
    onChange(value);
  };

  return /*#__PURE__*/React.createElement(Editor, {
    editorState: editorState,
    onChange: onDraftChange,
    placeholder: placeholder,
    ref: ref
  });
});
HighlightWithinTextarea.propTypes = process.env.NODE_ENV !== "production" ? {
  onChange: PropTypes.func,
  value: PropTypes.string.isRequired,
  highlight: PropTypes.oneOfType([PropTypes.string, PropTypes.array, PropTypes.instanceOf(RegExp)]),
  placeholder: PropTypes.string
} : {};
HighlightWithinTextarea.defaultProps = {
  highlight: null,
  placeholder: "Enter some text..."
};
export default HighlightWithinTextarea;